#
# spec file for package t-prot
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           t-prot
Summary:        A Display Filter for RFC822 Messages
License:        BSD-4-Clause
Group:          Productivity/Networking/Email/Utilities
Version:        3.4
Release:        5.5
Url:            http://www.escape.de/users/tolot/mutt/
Source:         http://www.escape.de/~tolot/mutt/t-prot/downloads/%{name}-%{version}.tar.gz
Source1:        muttrc.t-prot
Requires:       perl(Getopt::Long)
Requires:       perl(Locale::gettext)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
BuildRequires:  perl(Getopt::Long)
BuildRequires:  perl(Locale::gettext)

%description
t-prot detects and, when demanded, hides annoying parts in rfc822
messages: TOFU (see below), huge quoted blocks, signatures (especially
when they are too long), excessive punctuation, blocks of empty lines,
and trailing spaces and tabs. For use inside of MTAs or MDAs, it may
exit with appropriate libc exit codes, so annoying messages may be
bounced easily.

TOFU is an abbreviation that mixes German and English words. It expands
to "text oben, full-quote unten" that means "text above - full quote
below" and describes the style of many users who let their mailer or
newsreader quote everything of the previous message and just add some
text at the top.

%prep
%setup -q
cp %{SOURCE1} .

%build
sed -e "s#@docdir@#%{_defaultdocdir}/%{name}#g" t-prot.1 > x && mv x t-prot.1

%install
install -D -m 755 t-prot %{buildroot}%{_bindir}/t-prot
install -D -m 644 t-prot.1 %{buildroot}/%{_mandir}/man1/t-prot.1

%files
%defattr(-,root,root)
%doc ChangeLog README TODO muttrc.t-prot
%{_bindir}/t-prot
%{_mandir}/man1/t-prot.1.gz

%changelog
* Fri Mar 27 2015 p.drouand@gmail.com
- Update to version 3.4
  * t-prot, t-prot.1: Make documentation match Getopt::Long syntax:
  e.g. -c=1 is not supported, use -c1 instead.
- Changes from version 3.3
  * t-prot: Removed trailing whitespace.
  * t-prot: Small speedup: Run --pgp-short specific code only with
  - -pgp-short.
  * t-prot: Fixed a bug with -Mmutt and pgp signed and encrypted
    MIME/Multipart messages.
- Changes from version 3.2
  * t-prot: Make bigq work when MS Tofu is detected with no text
    above the quote, as with ZimbraWebClient.
  * t-prot.1: Fix spelling error.
  * t-prot.1: Update date string.
- Changes from version 3.1
  * t-prot, t-prot.1: Support mutt-kz
    (https://github.com/karelzak/mutt-kz) using -Mmutt-kz.
  * t-prot: Unicode fix for MS Outlook.
- Use download Url as source
* Wed Feb 26 2014 coolo@suse.com
- fix requires and install section
* Tue Jan 14 2014 dsterba@suse.com
- update to 3.0
  * t-prot: Umlauts always are so wrong. Hopefully Outlook mails in
    German are handled fine now.
  * t-prot.1: Make clear that --pgp-move and --pgp-move-vrf also work
    on SSL output.
  * t-prot: Coding style cleanup in pgp().
  * t-prot: Fix detection of unified diffs in the message body when
    using --diff.
  * t-prot.1: Update year.
  * contrib/t-prot.sl: Reflect transition to slang2 in comments.
  * contrib/t-prot.sl: Drop support for slang-1, default to slang-2.
  * t-prot, contrib/muttrc.t-prot: Drop support for mutt-1.4. Default
    to mutt-1.5.x strings.
  * t-prot: Fix eYou Webmail Tofu.
  * t-prot: Fix text/plain content-type detection with several user
    agents.
* Tue Mar 27 2012 cfarrell@suse.com
- license update: BSD-4-Clause
  BSD with advertising - use SPDX format
* Mon Nov  1 2010 puzel@novell.com
- update to 2.101
  * t-prot: Add line to make -m filter Lotus Domino Webserver
    produced TOFU.
  * t-prot: Use uniform syntax notation for parameters in command
    line options.
  * t-prot, t-prot.1: New command line option --fixind to fix broken
    quoting (regarding to RFC 3676).
* Fri Apr  9 2010 puzel@novell.com
- update to 2.98
  * Clarify --lax-security description.
  * Use descriptive temp variable names when parsing command line.
* Mon Mar 15 2010 puzel@novell.com
- update to 2.97.1
  * Mention configuration files for Heirloom mailx and
    metamail. Avoid false impression with --lax-security.
  * Another Typo.
  * Fix spelling error. Thanks to Gerfried Fuchs!
  * Standard diff(1) output now is protected by --diff, too.
* Fri Mar  5 2010 puzel@novell.com
- update to 2.96
  * Man page update.
  * Several small fixes and cleanups.
* Thu Mar  4 2010 puzel@novell.com
- update to 2.95
  * Use Getopt::Long.
  * The command line option -c now accepts an optional parameter
    specifying the number of empty lines to remain. Thanks to Simon
  Ruderich.
* Fri Feb 19 2010 puzel@novell.com
- update to 2.15
  * Fine-tune some regex.
  * Fix merging of multiple blank lines within pgp output
    using -Mmutt.
  * Add --reply and --sani for fixing annoying headers. Add
    documentation for both.  Many thanks to Matthias Kilian and
    Martin Neitzel for suggesting and providing some script invoked
    by procmail rules.
  * Code cleanup for --pgp-short. Should get better performance now.
  * By now, --bigq is pretty much standard and
    extremely well-tested, so we include it into default configuration.
* Mon Feb  1 2010 puzel@novell.com
- update to 2.13
  * Fix long standig false positive for mutt<1.5.18 with
  Microsoft TOFU inside a PGP signed message and no lines above the
  full quote (indicating a forwarded message rather than a lazy full
  quote).  Thanks to Gerfried Fuchs.
  * Fix newline stripping for locales.
* Tue Jan 19 2010 puzel@novell.com
- update to 2.12
  * Exit with exit status EX_OK when --max-lines
  hits and -Mmutt is set (mutt is picky when a display_filter
  fails). Provide a notification line in that case. Update man page.
* Tue Jan  5 2010 puzel@novell.com
- Update to 2.11
  * contrib/filter_innd.pl: Command line default has changed, check
  flags must be set now.
  * Fix initialization and command line parsing for
  - -check (this should work as advertised now). Make the ratio check
  code a little easier to read. Add the default value for the ratio
  check to the man page.
  * Do not check for message length in attachments (we
  checked already for the entire message). Do exit with proper exit
  code if message is longer than set in --max-lines (so scripts can
  see if we gave up processing).
  * Change check order and remove duplicated code for
  - -max-lines.
  * Fix a typo, thanks to Michael Hunger. Tweak the MS-TOFU
  pattern, thanks to Simon Ruderich.
* Thu Oct 18 2007 pth@suse.de
- Update to 2.5 which officially incorporates the Groupwise
  filtering:
  * Hide TOFU produced by Novell Groupwise.
* Wed Sep  5 2007 pth@suse.de
- Incorporate upstream patch that adds filtering groupwise
  style TOFU.
- Add an entry for --groupwise to the man page.
* Mon Mar 12 2007 pth@suse.de
- Update to 2.4. Changes since 1.99:
    t-prot:
  - Add feature to skip processing very large messages.
  - Fix formatting for better reading.
  - Add string to detect gmx.de's M$ style TOFU.
  - More tolerant handling of signatures -- trailing newlines
  are no longer counted as signature lines, thus fixing some
  mailing list software behaviour.
  - Detected MS TOFU hidden in MIME attachments.
  - The case-sensitivity of the Content-Type: header (vs.
    Content-type:) seems not to be absolutely clear. RFC 1049
    should be obsoleted by RFCs 2045-2049 by now, but to be
    sure, we will accept both strings.
  - More regex fixes.
  - Many fixes to many regexes, fixing performance issues und
    readability.  Some were entirely replaced by faster means.
  - We must not forget to remove ad and mailing list footers
  within the first MIME/Multipart attachment when processing
  raw messages (lacking -M).
  - Mailing list footers (and probably ad footers) were not
    detected when processing raw MIME/Multipart messages: We
    have to look at the very end of the message, not only at
    the end of the first attachment.  Fix this by calling
    remove_footers() before dealing with raw multipart
    attachments.
    t-prot.1:
  - Fix spelling and grammar.
  - Add section about performance issues.
  - Add section about exit status.
  - LICENSE CHANGE! it is the Right Thing to simply switch
  to a BSD license (slightly modified, as there is no binary
  code in t-prot).
  - RFC 822 is no longer important. RFC 2822 should
    suffice.
  - Add some clarifications and missing details.
    t-prot, t-prot.1:
  - Add --body to make sure we are not looking for
    any headers when there are none in the input.
    contrib/t-prot.sl:
  - Use S-Lang calls popen(), fputs(), and remove() instead of
    system() and pipe_article() to reduce flickering (and for
    cleaner code).
  - Mention mimedecode as filter for Quoted Printable.
  - Change key bindings: ESC-0 and ESC-1 are prefixes for
    other commands, so we should not overwrite those.
  - Make sure users get a hint if they look why t-prot.sl does
    not work on their system (just as I did and wondered what
    was wrong).
    contrib/filter_innd.pl:
  - We don't submit any headers, so use --body. Use unlink()
    instead of system(). Mention the temp file problem.
* Fri Feb  9 2007 meissner@suse.de
- build as nonroot.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Mar 29 2005 pth@suse.de
- Update to 1.99
* Mon Jan 10 2005 pth@suse.de
- Update to 1.48.1
* Mon Nov 25 2002 pthomas@suse.de
- Initial package creation.
